@@ -5,6 +5,7 @@ use warnings;
 use Carp;
 use Net::Whois::RIPE;
 use Data::Dumper;
+use IPC::Open2 qw/open2/;
 
 our $LWP;
 BEGIN {
@@ -87,12 +88,25 @@ B<CAUTION: SyncUpdates features require LWP::UserAgent to be installed.>
 
 Once the object has been modified, locally, you can create it in the database
 calling the syncupdates_create() method.
-The only parameter being the associated maintener's password.
-(Certificates are planned to be used in a near future)
+The only parameter being the associated maintener's authentication
+as a password or pgp key:
 
     $object->person('John Doe');
     ...
-    my $primary_key = $object->syncupdates_create($password);
+    my $primary_key = $object->syncupdates_create({ password => $password });
+    # or
+    my $primary_key = $object->syncupdates_create({ pgpkey   => $pgpkey   });
+
+The pgp key must be an eight digit hexadecimal key ID known to the local
+C<gpg> executable.
+
+If the C<pgpkey> key is present in the hash reference passed to
+syncupdates_create, you can also pass in the C<pgpexec> key to chose a program
+to execute for signing (C<gpg> by default), and C<pgpopts>, which must be an
+array reference of additional options to pass to the signing binary.
+
+For backwards compatibility, the password can be passed directly without
+using a a hash reference, C<< $object->syncupdates_create($password) >>.
 
 The primary key of the object created is returned.
 The attribute used as primary key can be obtained through 
@@ -102,25 +116,25 @@ $object->attribute('primary')
 
 An object existing in the RIPE database, can be retrived, modified locally
 and the updated through the syncupdates_update() method.
-The only parameter being the associated maintener's password.
-(Certificates are planned to be used in a near future)
+The only parameter being the associated maintener's authentication.
+See L</Create> for more information on the authentication methods.
 
     $object->person('John Doe');
     ...
-    $object->syncupdates_update($password);
+    $object->syncupdates_update($auth);
 
 =head4 Delete
 
 An object existing in the RIPE database, can be retrived, and deleted in
 the databased through the syncupdates_delete() method.
-The only required parameter being the associated maintener's password.
-(Certificates are planned to be used in a near future)
+The only required parameter being the associated maintener's authentication.
+See L</Create> for more information on the authentication methods.
 
-    $object->syncupdates_update($password);
+    $object->syncupdates_update($auth);
 
 An additional parameter can be used as a reason for the deletion.
 
-    $object->syncupdates_update($password,'Obsoleted by XXX');
+    $object->syncupdates_update($auth,'Obsoleted by XXX');
 
 If no reason is provided, a default one ('Not needed anymore') is used.
     
@@ -240,7 +254,7 @@ $type can be
 
     'primary'   Primary/Lookup key
     'mandatory' Required for update creation
-    'optionnal' Optionnal for update/creation
+    'optional' Optionnal for update/creation
     'multiple'  Can have multiple values
     'single'    Have only one value
     'all'       You can't specify attributes for this special type
@@ -254,9 +268,9 @@ Returns a list of attributes of the required type.
 sub attributes {
     my ( $self, $type, $ra_attributes ) = @_;
     if ( not defined $type or $type =~ /all/i ) {
-        return ( $self->attributes('mandatory'), $self->attributes('optionnal') );
+        return ( $self->attributes('mandatory'), $self->attributes('optional') );
     }
-    croak "Invalid attribute's type ($type)" unless $type =~ m/(all|primary|mandatory|optionnal|single|multiple)/i;
+    croak "Invalid attribute's type ($type)" unless $type =~ m/(all|primary|mandatory|optional|single|multiple)/i;
     if ($ra_attributes) {
         for my $a ( @{$ra_attributes} ) {
             $self->{TYPE}{$type}{$a} = 1;
@@ -368,12 +382,12 @@ Use the password passed as parameter to authenticate.
 =cut
 
 sub syncupdates_update {
-    my ( $self, $password ) = @_;
+    my ( $self, $auth ) = @_;
 
     my ($key)  = $self->attributes('primary');
     my $value = $self->_single_attribute_setget($key);
 
-    my $html = $self->_syncupdates_submit( $self->dump(), $password );
+    my $html = $self->_syncupdates_submit( $self->dump(), $auth );
     
     if ( $html =~ /Modify SUCCEEDED:.*$value/m ) {
         return $value;
@@ -387,12 +401,12 @@ sub syncupdates_update {
 
 Delete the object in the RIPE database through the web syncupdates interface.
 Use the password passed as parameter to authenticate.
-The optionnal parmeter reason is used to explain why the object is deleted.
+The optional parmeter reason is used to explain why the object is deleted.
 
 =cut
 
 sub syncupdates_delete {
-    my ( $self, $password, $reason ) = @_;
+    my ( $self, $auth, $reason) = @_;
 
     my ($key)  = $self->attributes('primary');
     my $value = $self->_single_attribute_setget($key);
@@ -401,7 +415,7 @@ sub syncupdates_delete {
     $reason = 'Not needed anymore' unless $reason;
     $text .= "delete: $reason\n";
 
-    my $html = $self->_syncupdates_submit( $text, $password );
+    my $html = $self->_syncupdates_submit( $text, $auth );
 
     if ( $html =~ /Delete SUCCEEDED:.*$value/m ) {
         return $value;
@@ -411,23 +425,23 @@ sub syncupdates_delete {
     }
 }
 
-=head2 B<syncupdates_create( $password )>
+=head2 B<syncupdates_create( $auth )>
 
 Create an object in the the RIPE database through the web syncupdates interface.
-Use the password passed as parameter to authenticate.
+See L</Create> for possible values of C<$auth>.
 
 Return the primary key of the object created.
 
 =cut
 
 sub syncupdates_create {
-    my ( $self, $password ) = @_;
+    my ( $self, $auth ) = @_;
 
     my ($key)  = $self->attributes('primary');
 
-    my $html = $self->_syncupdates_submit( $self->dump(), $password );
+    my $html = $self->_syncupdates_submit( $self->dump(), $auth );
 
-    if ( $html =~ /\*\*\*Info:\s+Authorisation for\s+\[.+\]\s+(\S+)\s*$/m ) {
+    if ( $html =~ /\*\*\*Info:\s+Authorisation for\[[^\]]+]\s+(.+)\s*$/m ) {
         my $value = $1;
         $self->_single_attribute_setget( $key, $value );
         return $value;
@@ -543,6 +557,21 @@ sub _multiple_attribute_setget {
     return $self->{$attribute};
 }
 
+=head2 B<_init( @options )>
+
+Initialize self with C<@options>
+
+=cut
+
+sub _init {
+    my ($self, @options) = @_;
+
+    while (my ($key, $val ) = splice(@options, 0, 2)) {
+        $self->$key( $val );
+    }
+}
+
+
 =head2 B<_syncupdates_submit( $text, $password )>
 
 Interact with the RIPE database through the web syncupdates interface.
@@ -553,12 +582,27 @@ The database used is chosen based on the 'source' attribute.
 Return the HTML code of the returned page.
 (This will change in a near future)
 
-=end UNDOCUMENTED
-
 =cut
 
 sub _syncupdates_submit {
-    my ( $self, $text, $password ) = @_;
+    my ( $self, $text, $auth ) = @_;
+
+    if ( $auth && !ref $auth) {
+        # preserve backwards compatiblity
+        $auth = { password => $auth };
+    }
+    $auth ||= {};
+
+    if ( exists $auth->{pgpkey} ) {
+        $text = $self->_pgp_sign($text, $auth);
+    }
+    elsif ( exists $auth->{password} ) {
+        my $password = $auth->{password};
+        chomp $password;
+        croak( "Passwords containing newlines are not supported" )
+            if $password =~ /\n/;
+        $text .= "password: $password\n" 
+    }
 
     croak "LWP::UserAgent required for updates" unless $LWP;    
 
@@ -566,7 +610,6 @@ sub _syncupdates_submit {
             ? 'http://syncupdates.db.ripe.net/'
             : 'http://syncupdates-test.db.ripe.net';
 
-    $text .= "password: $password\n" if $password;
 
     my $ua = LWP::UserAgent->new;
 
@@ -580,6 +623,40 @@ sub _syncupdates_submit {
     return $response_text;
 }
 
+=head2 B<_pgp_sign( $text, $auth )>
+
+Sign the C<$text> with the C<gpg> command and gpg information in C<$auth>
+Returns the signed text.
+
+=end UNDOCUMENTED
+
+=cut
+
+sub _pgp_sign {
+    my ( $self, $text, $auth ) = @_;
+    my $binary = $auth->{pgpexec} || 'gpg';
+    my $key_id = $auth->{pgpkey};
+    my @opts   = @{ $auth->{pgpopts} || [] };
+    $key_id =~ s/^0x//;
+    my $pid = open2(my $child_out, my $child_in,
+          $binary, "--local-user=$key_id", '--clearsign', @opts);
+    print { $child_in } $text;
+    close $child_in;
+
+    $text = do { local $/; <$child_out> };
+    close $child_out;
+
+    waitpid( $pid, 0 );
+    my $child_exit_status = $? >> 8;
+    if ($child_exit_status != 0) {
+        croak "Error while launching $binary for signing the message: "
+            . "child prcoess exited with status $child_exit_status";
+    }
+
+    return $text;
+}
+
+
 =head1 TODO
 
 The update part (in RIPE database) still needs a lot of work.
@@ -596,6 +673,9 @@ hours.
 Thanks to Luis Motta Campos for his trust when allowing me to publish this
 release.
 
+Thanks to Moritz Lenz for all his contributions
+(Thanks also to 'Noris Network AG', his employer for allowing him to contribute in the office hours)
+
 =cut
 
 1;
