@@ -37,17 +37,14 @@ Constructor for the Net::Whois::Object::Person class
 =cut
 
 sub new {
-    my ( $class, %options ) = @_;
+    my ( $class, @options ) = @_;
 
     my $self = bless {}, $class;
-
-    for my $key ( keys %options ) {
-        $self->$key( $options{$key} );
-    }
+    $self->_init(@options);
 
     $self->attributes( 'primary', ['nic_hdl'] );
     $self->attributes( 'mandatory', [ 'person', 'address', 'phone', 'nic_hdl', 'changed', 'source' ] );
-    $self->attributes( 'optionnal', [ 'fax_no', 'e_mail', 'remarks', 'notify', 'mnt_by' ] );
+    $self->attributes( 'optional', [ 'fax_no', 'e_mail', 'remarks', 'notify', 'mnt_by' ] );
     $self->attributes( 'single', [ 'person', 'nic_hdl', 'source' ] );
     $self->attributes( 'multiple', [ 'address', 'phone', 'changed', 'fax_no', 'e_mail', 'remarks', 'notify', 'mnt_by' ] );
 
